summaryrefslogtreecommitdiffstats
path: root/Lib/distutils/extension.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/distutils/extension.py')
-rw-r--r--Lib/distutils/extension.py8
1 files changed, 5 insertions, 3 deletions
diff --git a/Lib/distutils/extension.py b/Lib/distutils/extension.py
index 9d2a6fa..f0f68b9 100644
--- a/Lib/distutils/extension.py
+++ b/Lib/distutils/extension.py
@@ -31,9 +31,11 @@ class Extension:
the full name of the extension, including any packages -- ie.
*not* a filename or pathname, but Python dotted name
sources : [string]
- list of C/C++ source filenames, relative to the distribution
- root (where the setup script lives), in Unix form
- (slash-separated) for portability
+ list of source filenames, relative to the distribution root
+ (where the setup script lives), in Unix form (slash-separated)
+ for portability. Source files may be C, C++, SWIG (.i),
+ platform-specific resource files, or whatever else is recognized
+ by the "build_ext" command as source for a Python extension.
include_dirs : [string]
list of directories to search for C/C++ header files (in Unix
form for portability)